==> estateplat-common-1.2.3-20180426.014929-68-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 地役权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_dyq")
public class BdcDyq extends QllxParent implements QllxVo{
   /* @Id*/
    //    private String qlid;//权利Id
    //    private String bdcdyid;//不动产单元Id

    private String dyqnr;//地役权内容
    private Date dyqksqx;//地役权利用开始期限
    private Date dyqjsqx;//地役权利用结束期限
    private String ywh;//业务号
    private String qllx;//权利类型
    //    private String proid;//项目ID
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private String xydzl;//需役地坐落


    private String xydbdcdyh;//zdd 需役地不动产单元编号
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_dyq表增加冗余字段gydbdcdyh、gydbdcdybh、gydqlr、gydqlrzjzl、gydqlrzjh、xydqlr、xydqlrzjzl、xydqlrzjh、xydbdcdyh、bdcqzh、bdcqzmh
     */
    private String gydbdcdyh; //供役地不动产单元号

    private String gydqlr; //供役地不动产单元编号

    private String gydbdcdybh; //供役地权利人

    private String gydqlrzjzl; //供役地权利人证件种类

    private String gydqlrzjh; //供役地权利人证件号

    private String xydqlr; //需役地权利人

    private String xydqlrzjzl; //需役地权利人证件种类

    private String xydqlrzjh; //需役地权利人证件号

    private String xydbdcdybh; //需役地不动产单元编号

    private String bdcqzh; //不动产权证号

    private String bdcqzmh; //不动产权证明号

    public String getGydbdcdyh() {
        return gydbdcdyh;
    }

    public void setGydbdcdyh(String gydbdcdyh) {
        this.gydbdcdyh = gydbdcdyh;
    }

    public String getGydqlr() {
        return gydqlr;
    }

    public void setGydqlr(String gydqlr) {
        this.gydqlr = gydqlr;
    }

    public String getGydbdcdybh() {
        return gydbdcdybh;
    }

    public void setGydbdcdybh(String gydbdcdybh) {
        this.gydbdcdybh = gydbdcdybh;
    }

    public String getGydqlrzjzl() {
        return gydqlrzjzl;
    }

    public void setGydqlrzjzl(String gydqlrzjzl) {
        this.gydqlrzjzl = gydqlrzjzl;
    }

    public String getGydqlrzjh() {
        return gydqlrzjh;
    }

    public void setGydqlrzjh(String gydqlrzjh) {
        this.gydqlrzjh = gydqlrzjh;
    }

    public String getXydqlr() {
        return xydqlr;
    }

    public void setXydqlr(String xydqlr) {
        this.xydqlr = xydqlr;
    }

    public String getXydqlrzjzl() {
        return xydqlrzjzl;
    }

    public void setXydqlrzjzl(String xydqlrzjzl) {
        this.xydqlrzjzl = xydqlrzjzl;
    }

    public String getXydqlrzjh() {
        return xydqlrzjh;
    }

    public void setXydqlrzjh(String xydqlrzjh) {
        this.xydqlrzjh = xydqlrzjh;
    }

    public String getXydbdcdybh() {
        return xydbdcdybh;
    }

    public void setXydbdcdybh(String xydbdcdybh) {
        this.xydbdcdybh = xydbdcdybh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }


    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }


    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }



    public String getXydzl() {
        return xydzl;
    }

    public void setXydzl(String xydzl) {
        this.xydzl = xydzl;
    }

    public String getXydbdcdyh() {
        return xydbdcdyh;
    }

    public void setXydbdcdyh(String xydbdcdyh) {
        this.xydbdcdyh = xydbdcdyh;
    }


    public String getDyqnr() {
        return dyqnr;
    }

    public void setDyqnr(String dyqnr) {
        this.dyqnr = dyqnr;
    }

    public Date getDyqksqx() {
        return dyqksqx;
    }

    public void setDyqksqx(Date dyqksqx) {
        this.dyqksqx = dyqksqx;
    }

    public Date getDyqjsqx() {
        return dyqjsqx;
    }

    public void setDyqjsqx(Date dyqjsqx) {
        this.dyqjsqx = dyqjsqx;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

}

==> estateplat-common-1.2.3-20180628.061424-132-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 地役权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_dyq")
public class BdcDyq extends QllxParent implements QllxVo{
   /* @Id*/
    //    private String qlid;//权利Id
    //    private String bdcdyid;//不动产单元Id

    private String dyqnr;//地役权内容
    private Date dyqksqx;//地役权利用开始期限
    private Date dyqjsqx;//地役权利用结束期限
    private String ywh;//业务号
    private String qllx;//权利类型
    //    private String proid;//项目ID
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private String xydzl;//需役地坐落


    private String xydbdcdyh;//zdd 需役地不动产单元编号
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_dyq表增加冗余字段gydbdcdyh、gydbdcdybh、gydqlr、gydqlrzjzl、gydqlrzjh、xydqlr、xydqlrzjzl、xydqlrzjh、xydbdcdyh、bdcqzh、bdcqzmh
     */
    private String gydbdcdyh; //供役地不动产单元号

    private String gydqlr; //供役地不动产单元编号

    private String gydbdcdybh; //供役地权利人

    private String gydqlrzjzl; //供役地权利人证件种类

    private String gydqlrzjh; //供役地权利人证件号

    private String xydqlr; //需役地权利人

    private String xydqlrzjzl; //需役地权利人证件种类

    private String xydqlrzjh; //需役地权利人证件号

    private String xydbdcdybh; //需役地不动产单元编号

    private String bdcqzh; //不动产权证号

    private String bdcqzmh; //不动产权证明号
    private String qlqtzk; //权利其他状况
    public String getGydbdcdyh() {
        return gydbdcdyh;
    }

    public void setGydbdcdyh(String gydbdcdyh) {
        this.gydbdcdyh = gydbdcdyh;
    }

    public String getGydqlr() {
        return gydqlr;
    }

    public void setGydqlr(String gydqlr) {
        this.gydqlr = gydqlr;
    }

    public String getGydbdcdybh() {
        return gydbdcdybh;
    }

    public void setGydbdcdybh(String gydbdcdybh) {
        this.gydbdcdybh = gydbdcdybh;
    }

    public String getGydqlrzjzl() {
        return gydqlrzjzl;
    }

    public void setGydqlrzjzl(String gydqlrzjzl) {
        this.gydqlrzjzl = gydqlrzjzl;
    }

    public String getGydqlrzjh() {
        return gydqlrzjh;
    }

    public void setGydqlrzjh(String gydqlrzjh) {
        this.gydqlrzjh = gydqlrzjh;
    }

    public String getXydqlr() {
        return xydqlr;
    }

    public void setXydqlr(String xydqlr) {
        this.xydqlr = xydqlr;
    }

    public String getXydqlrzjzl() {
        return xydqlrzjzl;
    }

    public void setXydqlrzjzl(String xydqlrzjzl) {
        this.xydqlrzjzl = xydqlrzjzl;
    }

    public String getXydqlrzjh() {
        return xydqlrzjh;
    }

    public void setXydqlrzjh(String xydqlrzjh) {
        this.xydqlrzjh = xydqlrzjh;
    }

    public String getXydbdcdybh() {
        return xydbdcdybh;
    }

    public void setXydbdcdybh(String xydbdcdybh) {
        this.xydbdcdybh = xydbdcdybh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }


    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }


    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }



    public String getXydzl() {
        return xydzl;
    }

    public void setXydzl(String xydzl) {
        this.xydzl = xydzl;
    }

    public String getXydbdcdyh() {
        return xydbdcdyh;
    }

    public void setXydbdcdyh(String xydbdcdyh) {
        this.xydbdcdyh = xydbdcdyh;
    }


    public String getDyqnr() {
        return dyqnr;
    }

    public void setDyqnr(String dyqnr) {
        this.dyqnr = dyqnr;
    }

    public Date getDyqksqx() {
        return dyqksqx;
    }

    public void setDyqksqx(Date dyqksqx) {
        this.dyqksqx = dyqksqx;
    }

    public Date getDyqjsqx() {
        return dyqjsqx;
    }

    public void setDyqjsqx(Date dyqjsqx) {
        this.dyqjsqx = dyqjsqx;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }
}
